@@ -64,10 +64,10 @@ public final class LdapCreateTableService extends AbstractCreateTableImpl {
             " cid INT4 unsigned NOT NULL,\n" +
             " fid INT4 unsigned NOT NULL,\n" +
             " contact INT4 unsigned NOT NULL,\n" +
-            " ldapId VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL,\n" +
+            " ldapId VARCHAR(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL,\n" +
             " PRIMARY KEY (cid, fid, contact),\n" +
             " INDEX `ldapId` (cid, fid, ldapId)\n" +
-    		") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci"
+    		") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci"
     ;
 
     /**
